# azayaka

azayaka is a Python package for SAR (Synthetic Aperture Radar) processing and a simple InSAR Project.

and QGIS plugin SAR tools. It focuses on geometry calculations for JAXA CEOS and SICD formats.

## Installation

```bash
pip install azayaka
```

## Requirements

- Python 3.11+

## Usage

python
```python
foge = InSAR()
```

QGIS
```shell

```


## License

Licensed under the GNU Affero General Public License v3.0.
